@@ -3,11 +3,10 @@
 #' Define Fortify and Autoplot to Allow 'ggplot2' to Draw Some Popular Packages
 #'
 #' @name ggfortify
-#' @docType package
 #' @import methods ggplot2 dplyr
 #' @importFrom tidyr gather
 #' @importFrom gridExtra grid.arrange
 #' @importFrom utils installed.packages
 #' @importFrom stats complete.cases residuals weights as.formula reshape coef sd
 #' @importFrom stringr str_wrap
-NULL
+"_PACKAGE"
