@@ -395,9 +395,10 @@ setMethod('show', 'ggmultiplot', function(object) { print(object) })
 #' @method grid.draw ggmultiplot
 #' @importFrom grid grid.draw
 #' @importFrom gridExtra arrangeGrob
-#' @param plot \code{ggmultiplot}
-grid.draw.ggmultiplot <- function(plot) {
-  grid::grid.draw(gridExtra::arrangeGrob(grobs = plot@plots))
+#' @param x \code{ggmultiplot}
+#' @param recording \code{ggmultiplot}
+grid.draw.ggmultiplot <- function(x, recording = TRUE) {
+  grid::grid.draw(gridExtra::arrangeGrob(grobs = x@plots), recording = recording)
 }
 
 #' Post process for fortify. Based on \code{ggplot2::qplot}
@@ -484,6 +485,7 @@ autoplot.ggmultiplot <- function(object, ...) {
 #' @param loadings Logical value whether to display loadings arrows
 #' @param loadings.arrow An arrow definition
 #' @param loadings.colour Point colour for data
+#' @param loadings.linewidth Segment linewidth for loadings
 #' @param loadings.label Logical value whether to display loadings labels
 #' @param loadings.label.label Column name used for loadings text labels
 #' @param loadings.label.colour Colour for loadings text labels
@@ -526,6 +528,7 @@ ggbiplot <- function(plot.data, loadings.data = NULL,
                      loadings = FALSE,
                      loadings.arrow = grid::arrow(length = grid::unit(8, 'points')),
                      loadings.colour = '#FF0000',
+                     loadings.linewidth = 0.5,
                      loadings.label = FALSE,
                      loadings.label.label = 'rownames',
                      loadings.label.colour = '#FF0000',
@@ -547,6 +550,30 @@ ggbiplot <- function(plot.data, loadings.data = NULL,
                      ...) {
 #  print(label.position)
 
+  arguments <- list(...)
+
+  if ("color" %in% names(arguments)) {
+    if (missing(colour)) {
+      colour <- arguments[["color"]]
+    } else {
+      warning("both 'colour=' and 'color=' found, ignoring 'color='")
+    }
+  }
+  if ("loadings.color" %in% names(arguments)) {
+    if (missing(loadings.colour)) {
+      loadings.colour <- arguments[["loadings.color"]]
+    } else {
+      warning("both 'loadings.colour=' and 'loadings.color=' found, ignoring 'loadings.color='")
+    }
+  }
+  if ("loadings.label.color" %in% names(arguments)) {
+    if (missing(loadings.label.colour)) {
+      loadings.label.colour <- arguments[["loadings.label.color"]]
+    } else {
+      warning("both 'loadings.label.colour=' and 'loadings.label.color=' found, ignoring 'loadings.label.color='")
+    }
+  }
+
   plot.columns <- colnames(plot.data)
   mapping <- ggplot2::aes_string(x = plot.columns[1L], y = plot.columns[2L])
 
@@ -594,7 +621,8 @@ ggbiplot <- function(plot.data, loadings.data = NULL,
     p <- p + geom_segment(data = loadings.data,
                           mapping = loadings.mapping,
                           arrow = loadings.arrow,
-                          colour = loadings.colour)
+                          colour = loadings.colour,
+                          linewidth = loadings.linewidth)
     p <- plot_label(p = p, data = loadings.data, label = loadings.label,
                     label.label = loadings.label.label,
                     label.colour = loadings.label.colour,
